#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-I4fi8L52Ne3BgEspAnganO
key:                  yesod-form-1.7.9-I4fi8L52Ne3BgEspAnganO
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  cdafccb15a1f680e7f4754113d0629c9
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-I4fi8L52Ne3BgEspAnganO
depends:
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    attoparsec-0.14.4-FIfeiNzOKYm3sEc1QPF51Z base-4.18.2.1
    blaze-builder-0.4.4.1-IalnSqFtizaBKkEQN83UwH
    blaze-html-0.9.2.0-BSUXMYxgqldK7Fv9A0AXBj
    blaze-markup-0.8.3.0-F9gHjrjtMfj4BTHQBYRdEr
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    email-validate-2.3.2.21-Jq4x3KxCfnmAttnANvi9d2
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    persistent-2.14.5.2-3iklR6qVhbcHkfvtZeVIbd
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6
    shakespeare-2.1.7-CFRzD7VNGIS74GFY2KG4F1 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 wai-3.2.4-jofbQLzhHjJAjHqqQ1gcC
    xss-sanitize-0.3.7.2-3ee871HD590A3csUfOkl8b
    yesod-core-1.6.27.1-D6ElD4Y0bSo1oCdjSDIu6b
    yesod-persistent-1.6.0.8-IXCpoj5czPMAXNC4mk8CeY

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

